summaryrefslogtreecommitdiff
path: root/coreutils/id.c
diff options
context:
space:
mode:
Diffstat (limited to 'coreutils/id.c')
-rw-r--r--coreutils/id.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/coreutils/id.c b/coreutils/id.c
index 66874a7..35f945d 100644
--- a/coreutils/id.c
+++ b/coreutils/id.c
@@ -62,8 +62,8 @@ int id_main(int argc, char **argv)
if (argv[optind]) {
p = getpwnam(argv[optind]);
- /* bb_xgetpwnam is needed because it exits on failure */
- uid = bb_xgetpwnam(argv[optind]);
+ /* xuname2uid is needed because it exits on failure */
+ uid = xuname2uid(argv[optind]);
gid = p->pw_gid;
/* in this case PRINT_REAL is the same */
}